Learn R Programming

CLONETv2 (version 2.2.1)

allele_specific_cna_table_toy: Toy example of allele specific table of somatic copy number.

Description

Toy example of allele specific table of somatic copy number.

Usage

allele_specific_cna_table_toy

Arguments

Format

An object of class data.frame with 4 rows and 15 columns.