A ggplot2 plot reporting log2 on the x axis and beta and the y axis.
Each dot represents a segment of the input beta_table. Red transparent
circles corresponds to expected log2 vs beta position for different allele
specific copy number combinations given ploidy and admixture reported in
tables ploidy_table and admixture_table, respectively. Labels in the form
(cnA, cnB) indicate repsectively the major and minor allele copy number
value. Labels above the plot comprises sample name and ploddy/admixture estimates.