data.frame formatted as the output of function
compute_ploidy
min_required_snps
minimum number of informative snps in a segment
valid for computing ploidy (default=10)
min_coverage
minimum coverage of a segment valid for computing ploidy
(default=20)
error_tb
data.frame that reports for each combination of coverage and
number informative SNPs the expected estimation error around beta. The
data.frame error_tb must contains 3 columns:
mean.cov
mean coverage
n.info.snps
number of informative
SNPs
adm.estimation.error
estimated error on computed beta on a
segment with coverage mean.cov and n.info.snps informative SNPs
Package
CLONETv2 have built in error_tb named error_table (default=error_table)
library_type
WES, WGS (default=WES)
n_digits
number of digits in the output table (default=3)
n_cores
number of available cores for computation (default=1)
debug
return extra columns for debugging (default=F)
Value
A data.frame with two columns: sample that corresponds to column
sample of the input beta_table, and amd that represent the fraction of
estimated DNA admixture