Learn R Programming

CLONETv2 (version 2.2.1)

scna_clonality_table_toy: Toy example of clonality table of somatic copy number.

Description

Toy example of clonality table of somatic copy number.

Usage

scna_clonality_table_toy

Arguments

Format

An object of class data.frame with 4 rows and 25 columns.