allele_specific_cna_table_toy: Toy example of allele specific table of somatic copy number.
Description
Toy example of allele specific table of somatic copy number.
Usage
allele_specific_cna_table_toy
Format
An object of class data.frame with 4 rows and 15 columns.